"""
Date created: 6/11/2022

Purpose:

Details:

Description:

Notes:

IMPORTANT NOTES:

Explanation:

Tags:

Contributors:
    https://github.com/josephedradan

Reference:

"""
from code_analyzer.code_analyzer import CodeAnalyzer

# Pre-made instance
code_analyzer = CodeAnalyzer()
